.. Stetl documentation master file, created by
   sphinx-quickstart on Sun Jun  2 11:01:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Stetl
================

Stetl, Streaming ETL, is a toolkit for the transformation (ETL)
of geospatial data.  Stetl is based on existing ETL tools like GDAL/OGR and
XSLT. Stetl processing is driven from a configuration (.ini) file.
Stetl is written in Python and in particular suited for processing GML.

This is the documentation of the Stetl toolkit.
The code is on GitHub: https://github.com/justb4/stetl.

See an `introductory Stetl presentation at Slideshare <http://www.slideshare.net/justb4/stetl-foss4g20131024v1>`_.


Contents:

.. toctree::
   :maxdepth: 1

   intro.rst
   install.rst
   background.rst
   using.rst
   code.rst
   contact.rst
   links.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

